@@ -1,14 +1,19 @@
 # -*- coding: utf-8 -*-
-#-----------------------------------------------------------------------------
-# Copyright (c) IPython Development Team.
+# -----------------------------------------------------------------------------
+# Copyright (c) 2010 IPython Development Team
+# Copyright (c) 2013- Spyder Project Contributors
 #
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with IPython.
-#-----------------------------------------------------------------------------
+# Distributed under the terms of the Modified BSD License
+# (BSD 3-clause; see NOTICE.txt in the Spyder root directory for details).
+# -----------------------------------------------------------------------------
 
 """
-Calltip widget used only to show signatures
+Calltip widget used only to show signatures.
+
+Adapted from IPython/frontend/qt/console/call_tip_widget.py of the
+`IPython Project <https://github.com/ipython/ipython>`_.
+Now located at qtconsole/call_tip_widget.py as part of the
+`Jupyter QtConsole Project <https://github.com/jupyter/qtconsole>`_.
 """
 
 # Standard library imports
@@ -65,12 +70,17 @@ class CallTipWidget(QLabel):
 
             if etype == QEvent.KeyPress:
                 key = event.key()
+                cursor = self._text_edit.textCursor()
+                prev_char = self._text_edit.get_character(cursor.position(),
+                                                          offset=-1)
                 if key in (Qt.Key_Enter, Qt.Key_Return,
                            Qt.Key_Down, Qt.Key_Up):
                     self.hide()
                 elif key == Qt.Key_Escape:
                     self.hide()
                     return True
+                elif prev_char == ')':
+                    self.hide()
 
             elif etype == QEvent.FocusOut:
                 self.hide()
@@ -108,8 +118,12 @@ class CallTipWidget(QLabel):
         """ Reimplemented to disconnect signal handlers and event filter.
         """
         super(CallTipWidget, self).hideEvent(event)
-        self._text_edit.cursorPositionChanged.disconnect(
-            self._cursor_position_changed)
+        # This is needed for issue spyder-ide/spyder#9221
+        try:
+            self._text_edit.cursorPositionChanged.disconnect(
+                self._cursor_position_changed)
+        except TypeError:
+            pass
         self._text_edit.removeEventFilter(self)
 
     def leaveEvent(self, event):
