@@ -33,14 +33,15 @@ from qtpy.QtWidgets import (QApplication, QComboBox, QHBoxLayout, QLabel,
 
 # Local imports
 from spyder.config.base import _
-from spyder.py3compat import to_text_string
+from spyder.config.main import EXCLUDE_PATTERNS
+from spyder.py3compat import to_text_string, PY2
 from spyder.utils import icon_manager as ima
 from spyder.utils.encoding import is_text_file, to_unicode_from_fs
 from spyder.utils.misc import getcwd_or_home
 from spyder.widgets.comboboxes import PatternComboBox
 from spyder.widgets.onecolumntree import OneColumnTree
+from spyder.utils.misc import regexp_error_msg
 from spyder.utils.qthelpers import create_toolbutton, get_icon
-
 from spyder.config.gui import get_font
 from spyder.widgets.waitingspinner import QWaitingSpinner
 
@@ -84,14 +85,11 @@ class SearchThread(QThread):
         self.total_matches = None
         self.error_flag = None
         self.rootpath = None
-        self.python_path = None
-        self.hg_manifest = None
         self.exclude = None
         self.texts = None
         self.text_re = None
         self.completed = None
         self.case_sensitive = True
-        self.get_pythonpath_callback = None
         self.results = {}
         self.total_matches = 0
         self.is_file = False
@@ -99,9 +97,8 @@ class SearchThread(QThread):
     def initialize(self, path, is_file, exclude,
                    texts, text_re, case_sensitive):
         self.rootpath = path
-        self.python_path = False
-        self.hg_manifest = False
-        self.exclude = re.compile(exclude)
+        if exclude:
+            self.exclude = re.compile(exclude)
         self.texts = texts
         self.text_re = text_re
         self.is_file = is_file
@@ -139,12 +136,21 @@ class SearchThread(QThread):
                     return False
             try:
                 for d in dirs[:]:
+                    with QMutexLocker(self.mutex):
+                        if self.stopped:
+                            return False
                     dirname = os.path.join(path, d)
-                    if re.search(self.exclude, dirname + os.sep):
+                    if (self.exclude and
+                            re.search(self.exclude, dirname + os.sep)):
+                        dirs.remove(d)
+                    elif d == '.git' or d == '.hg':
                         dirs.remove(d)
                 for f in files:
+                    with QMutexLocker(self.mutex):
+                        if self.stopped:
+                            return False
                     filename = os.path.join(path, f)
-                    if re.search(self.exclude, filename):
+                    if self.exclude and re.search(self.exclude, filename):
                         continue
                     if is_text_file(filename):
                         self.find_string_in_file(filename)
@@ -159,6 +165,9 @@ class SearchThread(QThread):
         try:
             for lineno, line in enumerate(open(fname, 'rb')):
                 for text, enc in self.texts:
+                    with QMutexLocker(self.mutex):
+                        if self.stopped:
+                            return False
                     line_search = line
                     if not self.case_sensitive:
                         line_search = line_search.lower()
@@ -178,6 +187,9 @@ class SearchThread(QThread):
                     line = line.lower()
                 if self.text_re:
                     for match in re.finditer(text, line):
+                        with QMutexLocker(self.mutex):
+                            if self.stopped:
+                                return False
                         self.total_matches += 1
                         self.sig_file_match.emit((osp.abspath(fname),
                                                   lineno + 1,
@@ -187,6 +199,9 @@ class SearchThread(QThread):
                 else:
                     found = line.find(text)
                     while found > -1:
+                        with QMutexLocker(self.mutex):
+                            if self.stopped:
+                                return False
                         self.total_matches += 1
                         self.sig_file_match.emit((osp.abspath(fname),
                                                   lineno + 1,
@@ -385,23 +400,20 @@ class SearchInComboBox(QComboBox):
 
 class FindOptions(QWidget):
     """Find widget with options"""
-    REGEX_INVALID = "background-color:rgb(255, 175, 90);"
+    REGEX_INVALID = "background-color:rgb(255, 80, 80);"
+    REGEX_ERROR = _("Regular expression error")
+
     find = Signal()
     stop = Signal()
 
-    def __init__(self, parent, search_text, search_text_regexp, search_path,
+    def __init__(self, parent, search_text, search_text_regexp,
                  exclude, exclude_idx, exclude_regexp,
-                 supported_encodings, in_python_path, more_options,
+                 supported_encodings, more_options,
                  case_sensitive, external_path_history):
         QWidget.__init__(self, parent)
 
-        if search_path is None:
-            search_path = getcwd_or_home()
-
         if not isinstance(search_text, (list, tuple)):
             search_text = [search_text]
-        if not isinstance(search_path, (list, tuple)):
-            search_path = [search_path]
         if not isinstance(exclude, (list, tuple)):
             exclude = [exclude]
         if not isinstance(external_path_history, (list, tuple)):
@@ -414,7 +426,7 @@ class FindOptions(QWidget):
         self.search_text = PatternComboBox(self, search_text,
                                            _("Search pattern"))
         self.edit_regexp = create_toolbutton(self,
-                                             icon=ima.icon('advanced'),
+                                             icon=get_icon('regexp.svg'),
                                              tip=_('Regular expression'))
         self.case_button = create_toolbutton(self,
                                              icon=get_icon("upper_lower.png"),
@@ -436,7 +448,7 @@ class FindOptions(QWidget):
                                            text_beside_icon=True)
         self.ok_button.clicked.connect(self.update_combos)
         self.stop_button = create_toolbutton(self, text=_("Stop"),
-                                             icon=ima.icon('editclear'),
+                                             icon=ima.icon('stop'),
                                              triggered=lambda:
                                              self.stop.emit(),
                                              tip=_("Stop search"),
@@ -449,12 +461,12 @@ class FindOptions(QWidget):
         # Layout 2
         hlayout2 = QHBoxLayout()
         self.exclude_pattern = PatternComboBox(self, exclude,
-                                               _("Excluded filenames pattern"))
+                                               _("Exclude pattern"))
         if exclude_idx is not None and exclude_idx >= 0 \
            and exclude_idx < self.exclude_pattern.count():
             self.exclude_pattern.setCurrentIndex(exclude_idx)
         self.exclude_regexp = create_toolbutton(self,
-                                                icon=ima.icon('advanced'),
+                                                icon=get_icon('regexp.svg'),
                                                 tip=_('Regular expression'))
         self.exclude_regexp.setCheckable(True)
         self.exclude_regexp.setChecked(exclude_regexp)
@@ -513,14 +525,37 @@ class FindOptions(QWidget):
             self.search_text.lineEdit().selectAll()
         self.search_text.setFocus()
 
-    def get_options(self, all=False):
-        # Getting options
+    def get_options(self, to_save=False):
+        """Get options"""
+        text_re = self.edit_regexp.isChecked()
+        exclude_re = self.exclude_regexp.isChecked()
+        case_sensitive = self.case_button.isChecked()
+
+        # Return current options for them to be saved when closing
+        # Spyder.
+        if to_save:
+            search_text = [to_text_string(self.search_text.itemText(index))
+                           for index in range(self.search_text.count())]
+            exclude = [to_text_string(self.exclude_pattern.itemText(index))
+                       for index in range(self.exclude_pattern.count())]
+            exclude_idx = self.exclude_pattern.currentIndex()
+            path_history = self.path_selection_combo.get_external_paths()
+            more_options = self.more_options.isChecked()
+            return (search_text, text_re,
+                    exclude, exclude_idx,
+                    exclude_re, more_options,
+                    case_sensitive, path_history)
+
+        # Clear fields
         self.search_text.lineEdit().setStyleSheet("")
         self.exclude_pattern.lineEdit().setStyleSheet("")
+        self.search_text.setToolTip("")
+        self.exclude_pattern.setToolTip("")
 
         utext = to_text_string(self.search_text.currentText())
         if not utext:
             return
+
         try:
             texts = [(utext.encode('utf-8'), 'utf-8')]
         except UnicodeEncodeError:
@@ -530,11 +565,8 @@ class FindOptions(QWidget):
                     texts.append((utext.encode(enc), enc))
                 except UnicodeDecodeError:
                     pass
-        text_re = self.edit_regexp.isChecked()
+
         exclude = to_text_string(self.exclude_pattern.currentText())
-        exclude_re = self.exclude_regexp.isChecked()
-        case_sensitive = self.case_button.isChecked()
-        python_path = False
 
         if not case_sensitive:
             texts = [(text[0].lower(), text[1]) for text in texts]
@@ -542,37 +574,36 @@ class FindOptions(QWidget):
         file_search = self.path_selection_combo.is_file_search()
         path = self.path_selection_combo.get_current_searchpath()
 
-        # Finding text occurrences
         if not exclude_re:
-            exclude = fnmatch.translate(exclude)
-        else:
-            try:
-                exclude = re.compile(exclude)
-            except Exception:
+            items = [fnmatch.translate(item.strip())
+                     for item in exclude.split(",")
+                     if item.strip() != '']
+            exclude = '|'.join(items)
+
+        # Validate exclude regular expression
+        if exclude:
+            error_msg = regexp_error_msg(exclude)
+            if error_msg:
                 exclude_edit = self.exclude_pattern.lineEdit()
                 exclude_edit.setStyleSheet(self.REGEX_INVALID)
+                tooltip = self.REGEX_ERROR + u': ' + to_text_string(error_msg)
+                self.exclude_pattern.setToolTip(tooltip)
                 return None
+            else:
+                exclude = re.compile(exclude)
 
+        # Validate text regular expression
         if text_re:
-            try:
-                texts = [(re.compile(x[0]), x[1]) for x in texts]
-            except Exception:
+            error_msg = regexp_error_msg(texts[0][0])
+            if error_msg:
                 self.search_text.lineEdit().setStyleSheet(self.REGEX_INVALID)
+                tooltip = self.REGEX_ERROR + u': ' + to_text_string(error_msg)
+                self.search_text.setToolTip(tooltip)
                 return None
+            else:
+                texts = [(re.compile(x[0]), x[1]) for x in texts]
 
-        if all:
-            search_text = [to_text_string(self.search_text.itemText(index))
-                           for index in range(self.search_text.count())]
-            exclude = [to_text_string(self.exclude_pattern.itemText(index))
-                       for index in range(self.exclude_pattern.count())]
-            path_history = self.path_selection_combo.get_external_paths()
-            exclude_idx = self.exclude_pattern.currentIndex()
-            more_options = self.more_options.isChecked()
-            return (search_text, text_re, [],
-                    exclude, exclude_idx, exclude_re,
-                    python_path, more_options, case_sensitive, path_history)
-        else:
-            return (path, file_search, exclude, texts, text_re, case_sensitive)
+        return (path, file_search, exclude, texts, text_re, case_sensitive)
 
     @property
     def path(self):
@@ -760,29 +791,32 @@ class ResultsBrowser(OneColumnTree):
         self.set_title(title + text)
 
     def truncate_result(self, line, start, end):
-        ellipsis = '...'
+        ellipsis = u'...'
         max_line_length = 80
         max_num_char_fragment = 40
 
         html_escape_table = {
-            "&": "&amp;",
-            '"': "&quot;",
-            "'": "&apos;",
-            ">": "&gt;",
-            "<": "&lt;",
+            u"&": u"&amp;",
+            u'"': u"&quot;",
+            u"'": u"&apos;",
+            u">": u"&gt;",
+            u"<": u"&lt;",
         }
 
         def html_escape(text):
             """Produce entities within text."""
-            return "".join(html_escape_table.get(c, c) for c in text)
+            return u"".join(html_escape_table.get(c, c) for c in text)
 
-        line = to_text_string(line)
+        if PY2:
+            line = to_text_string(line, encoding='utf8')
+        else:
+            line = to_text_string(line)
         left, match, right = line[:start], line[start:end], line[end:]
 
         if len(line) > max_line_length:
             offset = (len(line) - len(match)) // 2
 
-            left = left.split(' ')
+            left = left.split(u' ')
             num_left_words = len(left)
 
             if num_left_words == 1:
@@ -791,7 +825,7 @@ class ResultsBrowser(OneColumnTree):
                     left = ellipsis + left[-offset:]
                 left = [left]
 
-            right = right.split(' ')
+            right = right.split(u' ')
             num_right_words = len(right)
 
             if num_right_words == 1:
@@ -809,8 +843,8 @@ class ResultsBrowser(OneColumnTree):
             if len(right) < num_right_words:
                 right = right + [ellipsis]
 
-            left = ' '.join(left)
-            right = ' '.join(right)
+            left = u' '.join(left)
+            right = u' '.join(right)
 
             if len(left) > max_num_char_fragment:
                 left = ellipsis + left[-30:]
@@ -818,7 +852,7 @@ class ResultsBrowser(OneColumnTree):
             if len(right) > max_num_char_fragment:
                 right = right[:30] + ellipsis
 
-        line_match_format = to_text_string('{0}<b>{1}</b>{2}')
+        line_match_format = u'{0}<b>{1}</b>{2}'
         left = html_escape(left)
         right = html_escape(right)
         match = html_escape(match)
@@ -901,27 +935,25 @@ class FindInFilesWidget(QWidget):
     sig_finished = Signal()
 
     def __init__(self, parent,
-                 search_text=r"# ?TODO|# ?FIXME|# ?XXX",
-                 search_text_regexp=True, search_path=None,
-                 exclude=r"\.pyc$|\.orig$|\.hg|\.svn", exclude_idx=None,
-                 exclude_regexp=True,
+                 search_text="",
+                 search_text_regexp=False,
+                 exclude=EXCLUDE_PATTERNS[0],
+                 exclude_idx=None,
+                 exclude_regexp=False,
                  supported_encodings=("utf-8", "iso-8859-1", "cp1252"),
-                 in_python_path=False, more_options=False,
-                 case_sensitive=True, external_path_history=[]):
+                 more_options=True,
+                 case_sensitive=False,
+                 external_path_history=[]):
         QWidget.__init__(self, parent)
 
         self.setWindowTitle(_('Find in files'))
 
         self.search_thread = None
-        self.search_path = ''
-        self.get_pythonpath_callback = None
-
         self.status_bar = FileProgressBar(self)
         self.status_bar.hide()
         self.find_options = FindOptions(self, search_text, search_text_regexp,
-                                        search_path,
                                         exclude, exclude_idx, exclude_regexp,
-                                        supported_encodings, in_python_path,
+                                        supported_encodings,
                                         more_options, case_sensitive,
                                         external_path_history)
         self.find_options.find.connect(self.find)
@@ -951,8 +983,6 @@ class FindInFilesWidget(QWidget):
             return
         self.stop_and_reset_thread(ignore_results=True)
         self.search_thread = SearchThread(self)
-        self.search_thread.get_pythonpath_callback = (
-            self.get_pythonpath_callback)
         self.search_thread.sig_finished.connect(self.search_complete)
         self.search_thread.sig_current_file.connect(
             lambda x: self.status_bar.set_label_path(x, folder=False)
